@@ -23,8 +23,6 @@ class LcovTest(CoverageTest):
         show the consequences of changes in the setup.
         """
         self.make_file("main_file.py", """\
-            #!/usr/bin/env python3
-
             def cuboid_volume(l):
                 return (l*l*l)
 
@@ -33,8 +31,6 @@ class LcovTest(CoverageTest):
             """)
 
         self.make_file("test_file.py", """\
-            #!/usr/bin/env python3
-
             from main_file import cuboid_volume
             import unittest
 
@@ -48,15 +44,13 @@ class LcovTest(CoverageTest):
 
     def get_lcov_report_content(self, filename: str = "coverage.lcov") -> str:
         """Return the content of an LCOV report."""
-        with open(filename, "r") as file:
+        with open(filename) as file:
             return file.read()
 
     def test_lone_file(self) -> None:
-        """For a single file with a couple of functions, the lcov should cover
-        the function definitions themselves, but not the returns."""
+        # For a single file with a couple of functions, the lcov should cover
+        # the function definitions themselves, but not the returns.
         self.make_file("main_file.py", """\
-            #!/usr/bin/env python3
-
             def cuboid_volume(l):
                 return (l*l*l)
 
@@ -66,10 +60,10 @@ class LcovTest(CoverageTest):
         expected_result = textwrap.dedent("""\
             TN:
             SF:main_file.py
-            DA:3,1,7URou3io0zReBkk69lEb/Q
-            DA:6,1,ilhb4KUfytxtEuClijZPlQ
-            DA:4,0,Xqj6H1iz/nsARMCAbE90ng
-            DA:7,0,LWILTcvARcydjFFyo9qM0A
+            DA:1,1,7URou3io0zReBkk69lEb/Q
+            DA:4,1,ilhb4KUfytxtEuClijZPlQ
+            DA:2,0,Xqj6H1iz/nsARMCAbE90ng
+            DA:5,0,LWILTcvARcydjFFyo9qM0A
             LF:4
             LH:2
             end_of_record
@@ -83,8 +77,8 @@ class LcovTest(CoverageTest):
         assert expected_result == actual_result
 
     def test_simple_line_coverage_two_files(self) -> None:
-        """Test that line coverage is created when coverage is run,
-        and matches the output of the file below."""
+        # Test that line coverage is created when coverage is run,
+        # and matches the output of the file below.
         self.create_initial_files()
         self.assert_doesnt_exist(".coverage")
         self.make_file(".coveragerc", "[lcov]\noutput = data.lcov\n")
@@ -96,23 +90,23 @@ class LcovTest(CoverageTest):
         expected_result = textwrap.dedent("""\
             TN:
             SF:main_file.py
-            DA:3,1,7URou3io0zReBkk69lEb/Q
-            DA:6,1,ilhb4KUfytxtEuClijZPlQ
-            DA:4,0,Xqj6H1iz/nsARMCAbE90ng
-            DA:7,0,LWILTcvARcydjFFyo9qM0A
+            DA:1,1,7URou3io0zReBkk69lEb/Q
+            DA:4,1,ilhb4KUfytxtEuClijZPlQ
+            DA:2,0,Xqj6H1iz/nsARMCAbE90ng
+            DA:5,0,LWILTcvARcydjFFyo9qM0A
             LF:4
             LH:2
             end_of_record
             TN:
             SF:test_file.py
-            DA:3,1,R5Rb4IzmjKRgY/vFFc1TRg
-            DA:4,1,E/tvV9JPVDhEcTCkgrwOFw
-            DA:6,1,GP08LPBYJq8EzYveHJy2qA
-            DA:7,1,MV+jSLi6PFEl+WatEAptog
-            DA:8,0,qyqd1mF289dg6oQAQHA+gQ
-            DA:9,0,nmEYd5F1KrxemgC9iVjlqg
-            DA:10,0,jodMK26WYDizOO1C7ekBbg
-            DA:11,0,LtxfKehkX8o4KvC5GnN52g
+            DA:1,1,R5Rb4IzmjKRgY/vFFc1TRg
+            DA:2,1,E/tvV9JPVDhEcTCkgrwOFw
+            DA:4,1,GP08LPBYJq8EzYveHJy2qA
+            DA:5,1,MV+jSLi6PFEl+WatEAptog
+            DA:6,0,qyqd1mF289dg6oQAQHA+gQ
+            DA:7,0,nmEYd5F1KrxemgC9iVjlqg
+            DA:8,0,jodMK26WYDizOO1C7ekBbg
+            DA:9,0,LtxfKehkX8o4KvC5GnN52g
             LF:8
             LH:4
             end_of_record
@@ -121,10 +115,8 @@ class LcovTest(CoverageTest):
         assert expected_result == actual_result
 
     def test_branch_coverage_one_file(self) -> None:
-        """Test that the reporter produces valid branch coverage."""
+        # Test that the reporter produces valid branch coverage.
         self.make_file("main_file.py", """\
-            #!/usr/bin/env python3
-
             def is_it_x(x):
                 if x == 3:
                     return x
@@ -140,14 +132,14 @@ class LcovTest(CoverageTest):
         expected_result = textwrap.dedent("""\
             TN:
             SF:main_file.py
-            DA:3,1,4MDXMbvwQ3L7va1tsphVzw
-            DA:4,0,MuERA6EYyZNpKPqoJfzwkA
-            DA:5,0,sAyiiE6iAuPMte9kyd0+3g
-            DA:7,0,W/g8GJDAYJkSSurt59Mzfw
+            DA:1,1,4MDXMbvwQ3L7va1tsphVzw
+            DA:2,0,MuERA6EYyZNpKPqoJfzwkA
+            DA:3,0,sAyiiE6iAuPMte9kyd0+3g
+            DA:5,0,W/g8GJDAYJkSSurt59Mzfw
             LF:4
             LH:1
-            BRDA:5,0,0,-
-            BRDA:7,0,1,-
+            BRDA:3,0,0,-
+            BRDA:5,0,1,-
             BRF:2
             BRH:0
             end_of_record
@@ -156,11 +148,9 @@ class LcovTest(CoverageTest):
         assert expected_result == actual_result
 
     def test_branch_coverage_two_files(self) -> None:
-        """Test that valid branch coverage is generated
-        in the case of two files."""
+        # Test that valid branch coverage is generated
+        # in the case of two files.
         self.make_file("main_file.py", """\
-            #!/usr/bin/env python3
-
             def is_it_x(x):
                 if x == 3:
                     return x
@@ -169,8 +159,6 @@ class LcovTest(CoverageTest):
             """)
 
         self.make_file("test_file.py", """\
-            #!/usr/bin/env python3
-
             from main_file import *
             import unittest
 
@@ -188,25 +176,25 @@ class LcovTest(CoverageTest):
         expected_result = textwrap.dedent("""\
             TN:
             SF:main_file.py
-            DA:3,1,4MDXMbvwQ3L7va1tsphVzw
-            DA:4,0,MuERA6EYyZNpKPqoJfzwkA
-            DA:5,0,sAyiiE6iAuPMte9kyd0+3g
-            DA:7,0,W/g8GJDAYJkSSurt59Mzfw
+            DA:1,1,4MDXMbvwQ3L7va1tsphVzw
+            DA:2,0,MuERA6EYyZNpKPqoJfzwkA
+            DA:3,0,sAyiiE6iAuPMte9kyd0+3g
+            DA:5,0,W/g8GJDAYJkSSurt59Mzfw
             LF:4
             LH:1
-            BRDA:5,0,0,-
-            BRDA:7,0,1,-
+            BRDA:3,0,0,-
+            BRDA:5,0,1,-
             BRF:2
             BRH:0
             end_of_record
             TN:
             SF:test_file.py
-            DA:3,1,9TxKIyoBtmhopmlbDNa8FQ
-            DA:4,1,E/tvV9JPVDhEcTCkgrwOFw
-            DA:6,1,C3s/c8C1Yd/zoNG1GnGexg
-            DA:7,1,9qPyWexYysgeKtB+YvuzAg
-            DA:8,0,LycuNcdqoUhPXeuXUTf5lA
-            DA:9,0,FPTWzd68bDx76HN7VHu1wA
+            DA:1,1,9TxKIyoBtmhopmlbDNa8FQ
+            DA:2,1,E/tvV9JPVDhEcTCkgrwOFw
+            DA:4,1,C3s/c8C1Yd/zoNG1GnGexg
+            DA:5,1,9qPyWexYysgeKtB+YvuzAg
+            DA:6,0,LycuNcdqoUhPXeuXUTf5lA
+            DA:7,0,FPTWzd68bDx76HN7VHu1wA
             LF:6
             LH:4
             BRF:0
@@ -217,9 +205,8 @@ class LcovTest(CoverageTest):
         assert actual_result == expected_result
 
     def test_half_covered_branch(self) -> None:
-        """Test that for a given branch that is only half covered,
-        the block numbers remain the same, and produces valid lcov.
-        """
+        # Test that for a given branch that is only half covered,
+        # the block numbers remain the same, and produces valid lcov.
         self.make_file("main_file.py", """\
             something = True
 
@@ -253,14 +240,13 @@ class LcovTest(CoverageTest):
         assert actual_result == expected_result
 
     def test_empty_init_files(self) -> None:
-        """Test that in the case of an empty __init__.py file, the lcov
-        reporter will note that the file is there, and will note the empty
-        line. It will also note the lack of branches, and the checksum for
-        the line.
-
-        Although there are no lines found, it will note one line as hit in
-        old Pythons, and no lines hit in newer Pythons.
-        """
+        # Test that in the case of an empty __init__.py file, the lcov
+        # reporter will note that the file is there, and will note the empty
+        # line. It will also note the lack of branches, and the checksum for
+        # the line.
+        #
+        # Although there are no lines found, it will note one line as hit in
+        # old Pythons, and no lines hit in newer Pythons.
 
         self.make_file("__init__.py", "")
         self.assert_doesnt_exist(".coverage")
